//  Stephen Smally © 2012
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 2 of the License, or
//      (at your option) any later version.
//      
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//      
//      You should have received a copy of the GNU General Public License
//      along with this program; if not, write to the Free Software
//      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
//      MA 02110-1301, USA.
//      

using Gtk;
using Lsc.Backend;
using Lsc.Widgets;

namespace Lsc {
    // Enum for trick-safe check
    public enum Section {
        GET = 0,
        INSTALLED = 1,
        BASKET = 2
    }
    
    // Css Styling
    public const string CSS_STYLE = """
    .LscCategoriesGrid .viewport {
        background-color: @base_color;
    }
    """;
    
    public class LscFrontend : Window {
        // Database Manager
        public LscDatabase db_manager;
        
        // Widgets
        public LscToolbar toolbar;
        //public LscPages pages;
        
        // Css
        public CssProvider styleprovider;
        
        public LscFrontend () {
            db_manager = new LscDatabase("/var/cache/lsc_packages.db"); // Need a settings check
            
            Box main_container = new Box(Orientation.VERTICAL, 0);
            toolbar = new LscToolbar();
            //pages = new LscPages();
            
            main_container.pack_start(toolbar, false, false, 0);
            //main_container.pack_start(pages, true, true, 0);
            
            styleprovider = new CssProvider();
            try {
                styleprovider.load_from_data(CSS_STYLE, CSS_STYLE.length);
            } catch (Error e) {
                stdout.printf("CssError: %s\n", e.message);
                stdout.printf("GtkViewport won't look as intended\n");
            }
            
            title = "Lubuntu Software Center";
            window_position = WindowPosition.CENTER;
            destroy.connect(Gtk.main_quit);
            add(main_container);
            show_all();
        }
    }
}

int main (string[] args) {
    Gtk.init(ref args);
    new Lsc.LscFrontend();
    Gtk.main();
    return 0;
}