//  Stephen Smally © 2012
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 2 of the License, or
//      (at your option) any later version.
//      
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//      
//      You should have received a copy of the GNU General Public License
//      along with this program; if not, write to the Free Software
//      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
//      MA 02110-1301, USA.
//      

using Gtk;

namespace Lsc.Widgets {
    public class LscToolbar : Toolbar {
        // Misc
        public signal void section_changed(int index);
        
        // Widgets
        public ToolButton back;
        public RadioToolButton radio = null;
        public SearchBar searchbar;
        
        public void on_changed_radio (ToolButton widget) {
            int index = get_children().index(widget)-1; // The radio position in the toolbar - 1
            section_changed(index);
        }
        
        public LscToolbar () {
            toolbar_style = ToolbarStyle.BOTH_HORIZ;
            get_style_context().add_class("primary-toolbar");
            show_arrow = false;
            
            back = new ToolButton.from_stock(Stock.GO_BACK);
            insert(back, -1);
            
            // This has to be fixed with the Section enum
            string[] SectionStrings = {
                "Get",
                "Installed",
                "Basket"
            };
            
            foreach (string section in SectionStrings) {
                if (radio == null) {
                    radio = new RadioToolButton(null);
                } else {
                    radio = new RadioToolButton.from_widget(radio);
                }
                radio.label = section;
                radio.icon_name = "applications-other";
                radio.set_is_important(true);
                radio.clicked.connect(on_changed_radio);
                insert(radio, -1);
            }
            
            ToolItem spacer = new ToolItem();
            spacer.set_expand(true);
            insert(spacer, -1);
            
            searchbar = new SearchBar("Search apps...");
            searchbar.text_changed_pause.connect((text) => {stdout.printf("%s\n", text); });
            ToolItem searchbar_tool = new ToolItem();
            searchbar_tool.add(searchbar);
            insert(searchbar_tool, -1);
        }
    }
}

